@@ -1,14 +1,26 @@
-# file MASS/cov.trob.q
+# file MASS/R/cov.trob.R
 # copyright (C) 1994-2004 W. N. Venables and B. D. Ripley
 #
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 or 3 of the License
+#  (at your option).
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  A copy of the GNU General Public License is available at
+#  http://www.r-project.org/Licenses/
+#
 cov.trob <- function(x, wt = rep(1, n), cor = FALSE, center = TRUE, nu = 5,
                      maxit = 25, tol = 0.01)
 {
     test.values <- function(x)
     {
         if(any(is.na(x)) || any(is.infinite(x)))
-            stop(paste("error in cov.trob: missing or infinite values in",
-                       deparse(substitute(x))))
+            stop("missing or infinite values in ", deparse(substitute(x)))
     }
     scale.simp <- function(x, center, n, p) x - rep(center, rep(n, p))
 
@@ -20,14 +32,14 @@ cov.trob <- function(x, wt = rep(1, n), cor = FALSE, center = TRUE, nu = 5,
     if(!(miss.wt <- missing(wt))) {
         test.values(wt)
         if(length(wt) != n)
-            stop("length of wt must equal number of observations")
+            stop("length of 'wt' must equal number of observations")
         if(any(wt < 0)) stop("negative weights not allowed")
         if(!sum(wt)) stop("no positive weights")
     }
 #    loc <- apply(wt * x, 2, sum)/sum(wt)
     loc <- colSums(wt * x)/sum(wt)
     if(is.numeric(center)) {
-        if(length(center) != p) stop("center is not the right length")
+        if(length(center) != p) stop("'center' is not the right length")
         loc <- center
     } else if(is.logical(center) && !center) loc <- rep(0, p)
     use.loc <- is.logical(center) && center
