@@ -1,6 +1,19 @@
-# file MASS/mca.q
+# file MASS/R/mca.R
 # copyright (C) 1994-9 W. N. Venables and B. D. Ripley
 #
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 or 3 of the License
+#  (at your option).
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  A copy of the GNU General Public License is available at
+#  http://www.r-project.org/Licenses/
+#
 mca <- function(df, nf = 2, abbrev = FALSE)
 {
   class.ind <- function(cl)
@@ -13,6 +26,7 @@ mca <- function(df, nf = 2, abbrev = FALSE)
   }
   if(!all(unlist(lapply(df, is.factor))))
     stop("all variables must be factors")
+  Call <- match.call()
   n <- nrow(df); p <- length(df)
   G <- as.matrix(do.call("data.frame", c(lapply(df, class.ind),
                                          check.names=FALSE)))
@@ -28,15 +42,15 @@ mca <- function(df, nf = 2, abbrev = FALSE)
   varnames <- if(abbrev) unlist(lapply(df, levels))
               else colnames(G)
   dimnames(cs) <- list(varnames, as.character(1:nf))
-  structure(list(rs=rs, cs=cs, fs=fs, d=X.svd$d[sec], p=p,
-                 call=match.call()), class="mca")
+  structure(list(rs=rs, cs=cs, fs=fs, d=X.svd$d[sec], p=p, call=Call),
+            class="mca")
 }
 
 print.mca <- function(x, ...)
 {
   if(!is.null(cl <- x$call)) {
     cat("Call:\n")
-    dput(c, control=NULL)
+    dput(cl, control=NULL)
   }
   cat("\nMultiple correspondence analysis of",
             nrow(x$rs), "cases of", x$p,
