@@ -1,7 +1,20 @@
-# file MASS/neg.bin.q
+# file MASS/R/neg.bin.R
 # copyright (C) 1994-2003 W. N. Venables and B. D. Ripley
 #
-neg.bin <- function(theta = stop("theta must be given"))
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 or 3 of the License
+#  (at your option).
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  A copy of the GNU General Public License is available at
+#  http://www.r-project.org/Licenses/
+#
+neg.bin <- function(theta = stop("'theta' must be given"))
 {
     ## use this to avoid capturing the MASS namespace
     env <- new.env(parent=.GlobalEnv)
